@@ -301,7 +301,7 @@
         return $problems;
     }
 
-    function findFileNameToCategoryToMessage($path)
+    function findFileNameToCategoryToMessage($path, $forcedCategory = 'Default')
     {
         assert('is_string($path)');
         assert('is_dir   ($path)');
@@ -341,7 +341,7 @@
                                 $attributeLabel = $model->getAttributeLabel($attributeName);
                                 if (isset($untranslatedLabels[$attributeName]))
                                 {
-                                    $translatedLabel = Yii::t('Default', $untranslatedLabels[$attributeName],
+                                    $translatedLabel = Zurmo::t('Core', $untranslatedLabels[$attributeName],
                                                                          LabelUtil::getTranslationParamsForAllModules());
                                     if ($untranslatedLabels[$attributeName] == $attributeLabel ||
                                        $translatedLabel != $attributeLabel)
@@ -456,6 +456,12 @@
                         {
                             foreach ($matches[1] as $index => $category)
                             {
+                                if ($forcedCategory
+                                    AND is_string($forcedCategory)
+                                    AND strlen($forcedCategory))
+                                {
+                                    $category = $forcedCategory;
+                                }
                                 if (!isset($fileNamesToCategoriesToMessages[$entry][$category]))
                                 {
                                     $fileNamesToCategoriesToMessages[$entry][$category] = array();
@@ -492,6 +498,26 @@
     {
         $labels   = array();
         $metadata = $moduleClassName::getMetadata();
+        if (isset($metadata['global']['adminTabMenuItems']))
+        {
+            foreach ($metadata['global']['adminTabMenuItems'] as $menuItem)
+            {
+                if (isset($menuItem['items']))
+                {
+                    foreach ($menuItem['items'] as $subMenuItem)
+                    {
+                        if (!in_array($subMenuItem['label'], $labels))
+                        {
+                            $labels[] = $subMenuItem['label'];
+                        }
+                    }
+                }
+                if (!in_array($menuItem['label'], $labels))
+                {
+                    $labels[] = $menuItem['label'];
+                }
+            }
+        }
         if (isset($metadata['global']['tabMenuItems']))
         {
             foreach ($metadata['global']['tabMenuItems'] as $menuItem)
