@@ -42,7 +42,7 @@
         {
             try
             {
-                $messageStreamer->add(Yii::t('Default', 'Checking permissions, files, upgrade version....'));
+                $messageStreamer->add(Zurmo::t('Core', 'Checking permissions, files, upgrade version....'));
                 $messageLogger = new MessageLogger($messageStreamer);
 
                 self::setUpgradeState('zurmoUpgradeTimestamp', time());
@@ -55,14 +55,14 @@
                 self::setUpgradeState('zurmoUpgradeFolderPath', $upgradeExtractPath);
 
                 $configuration = self::checkManifestIfVersionIsOk($upgradeExtractPath);
-                $messageStreamer->add(Yii::t('Default', 'Check completed.'));
-                $messageStreamer->add(Yii::t('Default', 'Loading UpgraderComponent.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Check completed.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Loading UpgraderComponent.'));
                 self::loadUpgraderComponent($upgradeExtractPath, $messageLogger);
-                $messageStreamer->add(Yii::t('Default', 'UpgraderComponent loaded.'));
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'UpgraderComponent loaded.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
                 self::clearCache();
 
-                $messageStreamer->add(Yii::t('Default', 'Altering configuration files.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Altering configuration files.'));
                 $pathToConfigurationFolder = COMMON_ROOT . DIRECTORY_SEPARATOR . 'protected' . DIRECTORY_SEPARATOR . 'config';
                 self::processBeforeConfigFiles();
                 self::processConfigFiles($pathToConfigurationFolder);
@@ -70,21 +70,21 @@
 
                 if (!$doNotlAlterFiles)
                 {
-                    $messageStreamer->add(Yii::t('Default', 'Copying files.'));
+                    $messageStreamer->add(Zurmo::t('Core', 'Copying files.'));
                     self::processBeforeFiles();
                     self::processFiles($upgradeExtractPath, $configuration);
                     self::processAfterFiles();
                 }
 
                 self::clearCache();
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
-                $messageStreamer->add(Yii::t('Default', 'Part 1 complete.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Part 1 complete.'));
             }
             catch (CException $e)
             {
-                $messageStreamer->add(Yii::t('Default', 'Error during upgrade!'));
+                $messageStreamer->add(Zurmo::t('Core', 'Error during upgrade!'));
                 $messageStreamer->add($e->getMessage());
-                $messageStreamer->add(Yii::t('Default', 'Please fix error(s) and try again, or restore your database/files.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Please fix error(s) and try again, or restore your database/files.'));
                 Yii::app()->end();
             }
         }
@@ -106,42 +106,42 @@
                 $messageLogger = new MessageLogger($messageStreamer);
 
                 self::isApplicationInUpgradeMode();
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
                 self::clearCache();
-                $messageStreamer->add(Yii::t('Default', 'Loading UpgraderComponent.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Loading UpgraderComponent.'));
                 self::loadUpgraderComponent($upgradeExtractPath, $messageLogger);
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
                 self::clearCache();
-                $messageStreamer->add(Yii::t('Default', 'Running tasks before updating schema.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Running tasks before updating schema.'));
                 self::processBeforeUpdateSchema();
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
                 self::clearCache();
-                $messageStreamer->add(Yii::t('Default', 'Updating schema.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Updating schema.'));
                 self::processUpdateSchema($messageLogger);
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
                 self::clearCache();
-                $messageStreamer->add(Yii::t('Default', 'Running tasks after schema is updated.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Running tasks after schema is updated.'));
                 self::processAfterUpdateSchema();
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
                 self::clearCache();
-                $messageStreamer->add(Yii::t('Default', 'Clearing assets and runtime folders.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing assets and runtime folders.'));
                 self::clearAssetsAndRunTimeItems();
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
                 self::clearCache();
-                $messageStreamer->add(Yii::t('Default', 'Processing final touches.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Processing final touches.'));
                 self::processFinalTouches();
-                $messageStreamer->add(Yii::t('Default', 'Clearing cache.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Clearing cache.'));
                 self::clearCache();
-                $messageStreamer->add(Yii::t('Default', 'Removing upgrade files.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Removing upgrade files.'));
                 self::removeUpgradeFiles($upgradeExtractPath);
                 self::unsetUpgradeState();
-                $messageStreamer->add(Yii::t('Default', 'Upgrade process completed.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Upgrade process completed.'));
             }
             catch (CException $e)
             {
-                $messageStreamer->add(Yii::t('Default', 'Error during upgrade!'));
+                $messageStreamer->add(Zurmo::t('Core', 'Error during upgrade!'));
                 $messageStreamer->add($e->getMessage());
-                $messageStreamer->add(Yii::t('Default', 'Please fix error(s) and try again, or restore your database/files.'));
+                $messageStreamer->add(Zurmo::t('Core', 'Please fix error(s) and try again, or restore your database/files.'));
                 Yii::app()->end();
             }
         }
@@ -155,7 +155,7 @@
         {
             if (isset(Yii::app()->maintenanceMode) && Yii::app()->maintenanceMode)
             {
-                $message = Yii::t('Default', 'Application is not in maintenance mode. Please edit perInstance.php file, and set "$maintenanceMode = true;"');
+                $message = Zurmo::t('Core', 'Application is not in maintenance mode. Please edit perInstance.php file, and set "$maintenanceMode = true;"');
                 throw new NotSupportedException($message);
             }
             return true;
@@ -172,7 +172,7 @@
             $nonWriteableFilesOrFolders = FileUtil::getNonWriteableFilesOrFolders(COMMON_ROOT);
             if (!empty($nonWriteableFilesOrFolders))
             {
-                $message = Yii::t('Default', 'Not all files and folders are writeable by upgrade user. Please make these files or folders writeable:');
+                $message = Zurmo::t('Core', 'Not all files and folders are writeable by upgrade user. Please make these files or folders writeable:');
                 foreach ($nonWriteableFilesOrFolders as $nonWriteableFileOrFolder)
                 {
                     $message .= $nonWriteableFileOrFolder . "\n";
@@ -192,7 +192,7 @@
             $isZipExtensionInstalled =  InstallUtil::checkZip();
             if (!$isZipExtensionInstalled)
             {
-                $message = Yii::t('Default', 'Zip PHP extension is required by upgrade process, please install it.');
+                $message = Zurmo::t('Core', 'Zip PHP extension is required by upgrade process, please install it.');
                 throw new NotSupportedException($message);
             }
             return true;
@@ -219,7 +219,7 @@
             $upgradePath = Yii::app()->getRuntimePath() . DIRECTORY_SEPARATOR . 'upgrade';
             if (!is_dir($upgradePath))
             {
-                $message = Yii::t('Default', 'Please upload upgrade zip file to runtime/upgrade folder.');
+                $message = Zurmo::t('Core', 'Please upload upgrade zip file to runtime/upgrade folder.');
                 throw new NotFoundException($message);
             }
 
@@ -237,7 +237,7 @@
             if ($numberOfZipFiles != 1)
             {
                 closedir($handle);
-                $message = Yii::t('Default', 'More then one zip file exists in runtime/upgrade folder. ' .
+                $message = Zurmo::t('Core', 'More then one zip file exists in runtime/upgrade folder. ' .
                                              'Please delete them all except the one that you want to use for the upgrade.');
                 throw new NotSupportedException($message);
             }
@@ -268,8 +268,8 @@
             }
             if (!$isExtracted)
             {
-                $message  = Yii::t('Default', 'There was an error during the extraction process of {zipFilePath}', array('{zipFilePath}' => $upgradeZipFilePath));
-                $message .= Yii::t('Default', 'Please check if the file is a valid zip archive.');
+                $message  = Zurmo::t('Core', 'There was an error during the extraction process of {zipFilePath}', array('{zipFilePath}' => $upgradeZipFilePath));
+                $message .= Zurmo::t('Core', 'Please check if the file is a valid zip archive.');
                 throw new NotSupportedException($message);
             }
             return $upgradeExtractPath . DIRECTORY_SEPARATOR . $fileInfo['filename'];
@@ -296,22 +296,22 @@
                     }
                     else
                     {
-                        $message  = Yii::t('Default', 'This upgrade is for Zurmo ({fromVersion} - {toVersion})',
+                        $message  = Zurmo::t('Core', 'This upgrade is for Zurmo ({fromVersion} - {toVersion})',
                             array ('{fromVersion}' => $upgradeFromVersionMatches[0], '{toVersion}' => $upgradeToVersionMatches[0]));
-                        $message .= Yii::t('Default', 'Installed Zurmo version is: {currentZurmoVersion}',
+                        $message .= Zurmo::t('Core', 'Installed Zurmo version is: {currentZurmoVersion}',
                             array('{currentZurmoVersion}' => $currentZurmoVersion));
                         throw new NotSupportedException($message);
                     }
                 }
                 else
                 {
-                    $message = Yii::t('Default', 'Could not extract upgrade "to version" in the manifest file.');
+                    $message = Zurmo::t('Core', 'Could not extract upgrade "to version" in the manifest file.');
                     throw new NotSupportedException($message);
                 }
             }
             else
             {
-                $message = Yii::t('Default', 'Could not extract upgrade "from version" in the manifest file.');
+                $message = Zurmo::t('Core', 'Could not extract upgrade "from version" in the manifest file.');
                 throw new NotSupportedException($message);
             }
         }
@@ -333,7 +333,7 @@
             }
             else
             {
-                $message = Yii::t('Default', 'Upgrade file is missing.');
+                $message = Zurmo::t('Core', 'Upgrade file is missing.');
                 throw new NotSupportedException($message);
             }
         }
