@@ -57,7 +57,7 @@
         {
             if (!$this->isApiTestUrlConfigured())
             {
-                $this->markTestSkipped(Yii::t('Default', 'API test url is not configured in perInstanceTest.php file.'));
+                $this->markTestSkipped(Zurmo::t('ApiModule', 'API test url is not configured in perInstanceTest.php file.'));
             }
             $this->assertTrue(strlen($this->serverUrl) > 0);
         }
