@@ -32,6 +32,9 @@
         const USER_EMAIL_CONFIGURATION_FILTER_PATH =
               'application.modules.emailMessages.controllers.filters.UserEmailConfigurationCheckControllerFilter';
 
+        const EMAIL_MESSAGES_REQUIRING_ARCHIVING_CONFIGURATION_FILTER_PATH =
+              'application.modules.emailMessages.controllers.filters.EmailMessagesRequiringArchivingCheckControllerFilter';
+
         public function filters()
         {
             $moduleClassName = get_class($this->getModule());
@@ -48,6 +51,9 @@
                 ),
                 array(self::USER_EMAIL_CONFIGURATION_FILTER_PATH . ' + createEmailMessage',
                      'controller' => $this,
+                ),
+                array(self::EMAIL_MESSAGES_REQUIRING_ARCHIVING_CONFIGURATION_FILTER_PATH . ' + matchingList' ,
+                     'controller' => $this,
                 )
             );
         }
@@ -80,7 +86,7 @@
                 {
                     EmailSmtpConfigurationFormAdapter::setConfigurationFromForm($configurationForm);
                     Yii::app()->user->setFlash('notification',
-                        Yii::t('Default', 'Email configuration saved successfully.')
+                        Zurmo::t('EmailMessagesModule', 'Email configuration saved successfully.')
                     );
                     $this->redirect(Yii::app()->createUrl('configuration/default/index'));
                 }
@@ -107,7 +113,7 @@
                 {
                     EmailArchivingConfigurationFormAdapter::setConfigurationFromForm($configurationForm);
                     Yii::app()->user->setFlash('notification',
-                        Yii::t('Default', 'Email configuration saved successfully.')
+                        Zurmo::t('EmailMessagesModule', 'Email configuration saved successfully.')
                     );
                     $this->redirect(Yii::app()->createUrl('configuration/default/index'));
                 }
@@ -145,6 +151,8 @@
                     $configurationForm->password        = $_POST['UserEmailConfigurationForm']['outboundPassword'];
                     $configurationForm->security        = $_POST['UserEmailConfigurationForm']['outboundSecurity'];
                     $configurationForm->aTestToAddress  = $_POST['UserEmailConfigurationForm']['aTestToAddress'];
+                    $fromNameToSendMessagesFrom         = $_POST['UserEmailConfigurationForm']['fromName'];
+                    $fromAddressToSendMessagesFrom      = $_POST['UserEmailConfigurationForm']['fromAddress'];
                 }
                 if ($configurationForm->aTestToAddress != null)
                 {
@@ -154,24 +162,35 @@
                     $emailHelper->outboundUsername = $configurationForm->username;
                     $emailHelper->outboundPassword = $configurationForm->password;
                     $emailHelper->outboundSecurity = $configurationForm->security;
-                    $userToSendMessagesFrom        = User::getById((int)$configurationForm->userIdOfUserToSendNotificationsAs);
-
-                    $emailMessage = EmailMessageHelper::sendTestEmail($emailHelper, $userToSendMessagesFrom,
-                                                                      $configurationForm->aTestToAddress);
-                    $messageContent  = null;
-                    if (!$emailMessage->hasSendError())
+                    if (isset($fromNameToSendMessagesFrom) && isset($fromAddressToSendMessagesFrom))
                     {
-                        $messageContent .= Yii::t('Default', 'Message successfully sent') . "\n";
+                        $from = array(
+                            'name'      => $fromNameToSendMessagesFrom,
+                            'address'   => $fromAddressToSendMessagesFrom
+                        );
+                        $emailMessage = EmailMessageHelper::sendTestEmail($emailHelper, $from,
+                                                                      $configurationForm->aTestToAddress);
                     }
                     else
                     {
-                        $messageContent .= Yii::t('Default', 'Message failed to send') . "\n";
+                        $userToSendMessagesFrom        = User::getById((int)$configurationForm->userIdOfUserToSendNotificationsAs);
+                        $emailMessage = EmailMessageHelper::sendTestEmailFromUser($emailHelper, $userToSendMessagesFrom,
+                                                                      $configurationForm->aTestToAddress);
+                    }
+                    $messageContent  = null;
+                    if (!$emailMessage->hasSendError())
+                    {
+                        $messageContent .= Zurmo::t('EmailMessagesModule', 'Message successfully sent') . "\n";
+                    }
+                    else
+                    {
+                        $messageContent .= Zurmo::t('EmailMessagesModule', 'Message failed to send') . "\n";
                         $messageContent .= $emailMessage->error     . "\n";
                     }
                 }
                 else
                 {
-                    $messageContent = Yii::t('Default', 'A test email address must be entered before you can send a test email.') . "\n";
+                    $messageContent = Zurmo::t('EmailMessagesModule', 'A test email address must be entered before you can send a test email.') . "\n";
                 }
                 Yii::app()->getClientScript()->setToAjaxMode();
                 $messageView = new TestEmailMessageView($messageContent);
@@ -211,16 +230,16 @@
                 catch (Exception $e)
                 {
                     $connect = false;
-                    $messageContent = Yii::t('Default', 'Could not connect to IMAP server.') . "\n";
+                    $messageContent = Zurmo::t('EmailMessagesModule', 'Could not connect to IMAP server.') . "\n";
                 }
 
                 if (isset($connect) && $connect == true)
                 {
-                    $messageContent = Yii::t('Default', 'Successfully connected to IMAP server.') . "\n";
+                    $messageContent = Zurmo::t('EmailMessagesModule', 'Successfully connected to IMAP server.') . "\n";
                 }
                 else
                 {
-                    $messageContent = Yii::t('Default', 'Could not connect to IMAP server.') . "\n";
+                    $messageContent = Zurmo::t('EmailMessagesModule', 'Could not connect to IMAP server.') . "\n";
                 }
 
                 Yii::app()->getClientScript()->setToAjaxMode();
@@ -228,7 +247,7 @@
                 $view = new ModalView($this,
                                       $messageView,
                                       'modalContainer',
-                                      Yii::t('Default', 'Test Message Results')
+                                      Zurmo::t('EmailMessagesModule', 'Test Message Results')
                 );
                 echo $view->render();
             }
@@ -268,7 +287,7 @@
                                         'EmailMessage',
                                         $dataProvider,
                                         'ArchivedEmailMatchingListView',
-                                        Yii::t('Default', 'Unmatched Archived Emails'),
+                                        Zurmo::t('EmailMessagesModule', 'Unmatched Archived Emails'),
                                         array(),
                                         false);
             $view = new EmailMessagesPageView(ZurmoDefaultViewUtil::
@@ -334,11 +353,7 @@
                     $contact = new Contact();
                     $contact->setAttributes($_POST[$type][$emailMessageId]);
                     $contact->validate();
-                    $errorData = array();
-                    foreach ($contact->getErrors() as $attribute => $errors)
-                    {
-                            $errorData[ZurmoHtml::activeId($contact, $attribute)] = $errors;
-                    }
+                    $errorData = ZurmoActiveForm::makeErrorsDataAndResolveForOwnedModelAttributes($contact);
                     echo CJSON::encode($errorData);
                     Yii::app()->end(0, false);
                 }
@@ -514,11 +529,7 @@
                 }
                 else
                 {
-                    $errorData = array();
-                    foreach ($emailMessageForm->getErrors() as $attribute => $errors)
-                    {
-                            $errorData[ZurmoHtml::activeId($emailMessageForm, $attribute)] = $errors;
-                    }
+                    $errorData = ZurmoActiveForm::makeErrorsDataAndResolveForOwnedModelAttributes($emailMessageForm);
                     echo CJSON::encode($errorData);
                 }
                 Yii::app()->end(false);
