@@ -639,9 +639,9 @@
         {
             $this->runInstallation(true);
             $messageLogger = new MessageLogger();
-            $messageLogger->addInfoMessage(Yii::t('Default', 'Starting schema update process.'));
+            $messageLogger->addInfoMessage(Zurmo::t('InstallModule', 'Starting schema update process.'));
             $result = InstallUtil::runAutoBuildFromUpdateSchemaCommand($messageLogger);
-            $messageLogger->addInfoMessage(Yii::t('Default', 'Schema update complete.'));
+            $messageLogger->addInfoMessage(Zurmo::t('InstallModule', 'Schema update complete.'));
             $this->assertTrue($result);
         }
 
