@@ -70,13 +70,15 @@
                                               'listPageSize', get_class($this->getModule()));
             $user                           = new User(false);
             $searchForm                     = new UsersSearchForm($user);
+            $listAttributesSelector         = new ListAttributesSelector('UsersListView', get_class($this->getModule()));
+            $searchForm->setListAttributesSelector($listAttributesSelector);
             $dataProvider = $this->resolveSearchDataProvider(
                 $searchForm,
                 $pageSize,
                 null,
                 'UsersSearchView'
             );
-            $title           = Yii::t('Default', 'Users');
+            $title           = Zurmo::t('UsersModule', 'Users');
             $breadcrumbLinks = array(
                  $title,
             );
@@ -90,13 +92,7 @@
             }
             else
             {
-                $mixedView = $this->makeActionBarSearchAndListView(
-                    $searchForm,
-                    $pageSize,
-                    UsersModule::getModuleLabelByTypeAndLanguage('Plural'),
-                    $dataProvider,
-                    'UsersActionBarForSearchAndListView'
-                );
+                $mixedView = $this->makeActionBarSearchAndListView($searchForm, $dataProvider, 'UsersActionBarForSearchAndListView');
                 $view = new UsersPageView(ZurmoDefaultAdminViewUtil::
                                          makeViewWithBreadcrumbsForCurrentUser($this, $mixedView, $breadcrumbLinks, 'UserBreadCrumbView'));
             }
@@ -127,7 +123,7 @@
         public function actionDetails($id)
         {
             $user = User::getById(intval($id));
-            $title           = Yii::t('Default', 'Profile');
+            $title           = Zurmo::t('UsersModule', 'Profile');
             $breadcrumbLinks = array(strval($user) => array('default/details',  'id' => $id), $title);
             AuditEvent::logAuditEvent('ZurmoModule', ZurmoModule::AUDIT_EVENT_ITEM_VIEWED, array(strval($user), 'UsersModule'), $user);
             $params = array(
@@ -154,7 +150,7 @@
 
         public function actionCreate()
         {
-            $title           = Yii::t('Default', 'Create User');
+            $title           = Zurmo::t('UsersModule', 'Create User');
             $breadcrumbLinks = array($title);
             $user             = new User();
             $user->language   = Yii::app()->language;
@@ -176,7 +172,7 @@
             UserAccessUtil::resolveCanCurrentUserAccessAction(intval($id));
             $user            = User::getById(intval($id));
             $user->setScenario('editUser');
-            $title           = Yii::t('Default', 'Details');
+            $title           = Zurmo::t('UsersModule', 'Details');
             $breadcrumbLinks = array(strval($user) => array('default/details',  'id' => $id), $title);
             $this->attemptToValidateAjaxFromPost($user, 'User');
             if ($user == Yii::app()->user->userModel)
@@ -209,7 +205,7 @@
         {
             UserAccessUtil::resolveCanCurrentUserAccessAction(intval($id));
             $user = User::getById(intval($id));
-            $title           = Yii::t('Default', 'Change Password');
+            $title           = Zurmo::t('UsersModule', 'Change Password');
             $breadcrumbLinks = array(strval($user) => array('default/details',  'id' => $id), $title);
             $user->setScenario('changePassword');
             $userPasswordForm = new UserPasswordForm($user);
@@ -240,7 +236,7 @@
                     }
                 }
             }
-            $title                         = Yii::t('Default', 'Confirm your time zone');
+            $title                         = Zurmo::t('UsersModule', 'Confirm your time zone');
             $timeZoneView                  = new UserTimeZoneConfirmationView($this->getId(),
                                                                  $this->getModule()->getId(),
                                                                  $confirmTimeZoneForm,
@@ -396,7 +392,7 @@
         {
             UserAccessUtil::resolveCanCurrentUserAccessAction(intval($id));
             $user = User::getById(intval($id));
-            $title           = Yii::t('Default', 'Security');
+            $title           = Zurmo::t('UsersModule', 'Security Overview');
             $breadcrumbLinks = array(strval($user) => array('default/details',  'id' => $id), $title);
             $modulePermissionsData =  PermissionsUtil::getAllModulePermissionsDataByPermitable($user);
             $modulePermissionsForm = ModulePermissionsFormUtil::makeFormFromPermissionsData($modulePermissionsData);
@@ -437,7 +433,7 @@
         {
             UserAccessUtil::resolveCanCurrentUserAccessAction(intval($id));
             $user = User::getById(intval($id));
-            $title           = Yii::t('Default', 'Configuration');
+            $title           = Zurmo::t('UsersModule', 'Configuration');
             $breadcrumbLinks = array(strval($user) => array('default/details',  'id' => $id), $title);
             $configurationForm = UserConfigurationFormAdapter::makeFormFromUserConfigurationByUser($user);
             $postVariableName   = get_class($configurationForm);
@@ -455,7 +451,7 @@
                         UserConfigurationFormAdapter::setConfigurationFromFormForCurrentUser($configurationForm);
                     }
                     Yii::app()->user->setFlash('notification',
-                        Yii::t('Default', 'User configuration saved successfully.')
+                        Zurmo::t('UsersModule', 'User configuration saved successfully.')
                     );
                     $this->redirect(array($this->getId() . '/details', 'id' => $user->id));
                 }
@@ -476,7 +472,7 @@
         {
             UserAccessUtil::resolveCanCurrentUserAccessAction(intval($id));
             $user  = User::getById(intval($id));
-            $title = Yii::t('Default', 'Email Configuration');
+            $title = Zurmo::t('UsersModule', 'Email Configuration');
             $breadcrumbLinks = array(strval($user) => array('default/details',  'id' => $id), $title);
             $emailAccount = EmailAccount::resolveAndGetByUserAndName($user);
             $userEmailConfigurationForm = new UserEmailConfigurationForm($emailAccount);
@@ -490,7 +486,7 @@
                 {
                     $userEmailConfigurationForm->save();
                     Yii::app()->user->setFlash('notification',
-                        Yii::t('Default', 'User email configuration saved successfully.')
+                        Zurmo::t('UsersModule', 'User email configuration saved successfully.')
                     );
                     $this->redirect(array($this->getId() . '/details', 'id' => $user->id));
                 }
