@@ -332,28 +332,29 @@
             $this->assertTrue(Right::NONE == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_WEB));
             $this->assertTrue(Right::NONE == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_MOBILE));
             $this->assertTrue(Right::NONE == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_WEB_API));
+            $this->assertEquals(1, $user->isActive);
 
-            //Change the user's status to inactive and confirm the changes in rights.
+            //Change the user's status to inactive and confirm the changes in rights and isActive attribute.
             $this->setGetArray(array('id' => $user->id));
             $this->setPostArray(array('User' => array('userStatus'  => UserStatusUtil::INACTIVE)));
             $this->runControllerWithRedirectExceptionAndGetContent('users/default/edit');
-
             $userId     = $user->id;
             $user       = User::getById($userId);
             $this->assertTrue(Right::DENY == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_WEB));
             $this->assertTrue(Right::DENY == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_MOBILE));
             $this->assertTrue(Right::DENY == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_WEB_API));
+            $this->assertEquals(0, $user->isActive);
 
             //Now change the user's status back to active.
             $this->setGetArray(array('id' => $user->id));
             $this->setPostArray(array('User' => array('userStatus'  => UserStatusUtil::ACTIVE)));
             $this->runControllerWithRedirectExceptionAndGetContent('users/default/edit');
-
             $userId     = $user->id;
             $user       = User::getById($userId);
             $this->assertTrue(Right::NONE == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_WEB));
             $this->assertTrue(Right::NONE == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_MOBILE));
             $this->assertTrue(Right::NONE == $user->getExplicitActualRight ('UsersModule', UsersModule::RIGHT_LOGIN_VIA_WEB_API));
+            $this->assertEquals(1, $user->isActive);
         }
 
         /**
