@@ -98,7 +98,7 @@
                 Yii::import('application.extensions.sentrylog.RSentryLog');
                 $rSentryLog = Yii::createComponent(
                     array('class' => 'RSentryLog', 'dsn' => Yii::app()->params['sentryDsn']));
-                //Have to invoke component init(), because it is not caled automatically
+                // Have to invoke component init(), because it is not called automatically
                 $rSentryLog->init();
                 $component   = Yii::app()->getComponent('log');
                 $allRoutes   = $component->getRoutes();
@@ -122,8 +122,9 @@
                 if ($memcacheServiceHelper->runCheckAndGetIfSuccessful())
                 {
                     $cacheComponent = Yii::createComponent(array(
-                        'class' => 'CMemCache',
-                        'servers' => Yii::app()->params['memcacheServers']));
+                        'class'     => 'CMemCache',
+                        'keyPrefix' => ZURMO_TOKEN,
+                        'servers'   => Yii::app()->params['memcacheServers']));
                     Yii::app()->setComponent('cache', $cacheComponent);
                 }
                 // todo: Find better way to append this prefix for tests.
@@ -182,7 +183,7 @@
         {
             if (!RedBeanDatabaseBuilderUtil::isAutoBuildStateValid())
             {
-                echo Yii::t('Default', 'Database upgrade not completed. Please try again later.');
+                echo Zurmo::t('ZurmoModule', 'Database upgrade not completed. Please try again later.');
                 Yii::app()->end(0, false);
             }
         }
@@ -254,6 +255,7 @@
                 $allowedTimeZoneConfirmBypassUrls = array (
                     Yii::app()->createUrl('users/default/confirmTimeZone'),
                     Yii::app()->createUrl('min/serve'),
+                    Yii::app()->createUrl('zurmo/default/logout'),
                 );
                 $reqestedUrl = Yii::app()->getRequest()->getUrl();
                 $isUrlAllowedToByPass = false;
@@ -307,13 +309,13 @@
                         $group = Group::getByName(Group::SUPER_ADMINISTRATORS_GROUP_NAME);
                         if (!$group->users->contains(Yii::app()->user->userModel))
                         {
-                            echo Yii::t('Default', 'Application is in maintenance mode. Please try again later.');
+                            echo Zurmo::t('ZurmoModule', 'Application is in maintenance mode. Please try again later.');
                             exit;
                         }
                         else
                         {
                             // Super Administrators can access all pages, but inform them that application is in maintenance mode.
-                            Yii::app()->user->setFlash('notification', Yii::t('Default', 'Application is in maintenance mode, and only Super Administrators can access it.'));
+                            Yii::app()->user->setFlash('notification', Zurmo::t('ZurmoModule', 'Application is in maintenance mode, and only Super Administrators can access it.'));
                         }
                     }
                 }
@@ -324,7 +326,7 @@
         {
             if (Yii::app()->isApplicationInMaintenanceMode())
             {
-                $message = Yii::t('Default', 'Application is in maintenance mode. Please try again later.');
+                $message = Zurmo::t('ZurmoModule', 'Application is in maintenance mode. Please try again later.');
                 $result = new ApiResult(ApiResponse::STATUS_FAILURE, null, $message, null);
                 Yii::app()->apiHelper->sendResponse($result);
                 exit;
@@ -347,7 +349,7 @@
 
                 if (!$isUrlAllowedToGuests)
                 {
-                    $message = Yii::t('Default', 'Sign in required.');
+                    $message = Zurmo::t('ZurmoModule', 'Sign in required.');
                     $result = new ApiResult(ApiResponse::STATUS_FAILURE, null, $message, null);
                     Yii::app()->apiHelper->sendResponse($result);
                     exit;
@@ -363,14 +365,14 @@
             $yiiVersion     =  YiiBase::getVersion();
             if ( $redBeanVersion != Yii::app()->params['redBeanVersion'])
             {
-                echo Yii::t('Default', 'Your RedBean version is currentVersion and it should be acceptableVersion.',
+                echo Zurmo::t('ZurmoModule', 'Your RedBean version is currentVersion and it should be acceptableVersion.',
                                 array(  'currentVersion' => $redBeanVersion,
                                         'acceptableVersion' => Yii::app()->params['redBeanVersion']));
                 Yii::app()->end(0, false);
             }
             if ( $yiiVersion != Yii::app()->params['yiiVersion'])
             {
-                echo Yii::t('Default', 'Your Yii version is currentVersion and it should be acceptableVersion.',
+                echo Zurmo::t('ZurmoModule', 'Your Yii version is currentVersion and it should be acceptableVersion.',
                                 array(  'currentVersion' => $yiiVersion,
                                         'acceptableVersion' => Yii::app()->params['yiiVersion']));
                 Yii::app()->end(0, false);
