@@ -563,7 +563,7 @@
             => 'E-mail secondaire',
         'Securable Item'
             => 'Élément sécurisable',
-        'Security'
+        'Security Overview'
             => 'Sécurité',
         'See more search results by clicking the down arrow at the bottom of the screen.'
             => 'Cliquez sur la flèche vers le bas pour afficher plus de résultats de votre recherche.',
@@ -687,6 +687,8 @@
             => 'Membres du groupe sauvegardé.',
         'Username'
             => 'Nom d\'utilisateur',
+        'Users'
+            => 'Users',
         'Value'
             => 'Valeur',
         'Values'
@@ -705,6 +707,8 @@
             => 'Aide',
         'Who can read and write'
             => 'Autorisation lecture/écriture',
+        'Who can read and write - Default'
+            => 'Autorisation lecture/écriture',
         'Word of Mouth'
             => 'Bouche à oreille',
         'Write'
