@@ -73,7 +73,7 @@
                     });
                     $('#" . $this->getRowCounterInputId() . "').val(0);
                     $('#" . $this->getStructureInputId() . "').val('');
-                    $('.search-view-1').hide();
+                    $(this).closest('form').find('.search-view-1').hide();
                     $('.select-list-attributes-view').hide();
                     resolveClearLinkPrefixLabelAndVisibility('" . $this->getSearchFormId() . "');
                     rebuildDynamicSearchRowNumbersAndStructureInput('" . $this->getSearchFormId() . "')
@@ -105,7 +105,7 @@
 
         protected function renderConfigSaveAjax($formName)
         {
-            return     "$('.search-view-1').hide();
+            return     "$(this).closest('form').find('.search-view-1').hide();
                         $('.select-list-attributes-view').hide();
                         $('#" . $formName . "').find('.attachLoading:first').removeClass('loading');
                         $('#" . $formName . "').find('.attachLoading:first').removeClass('loading-ajax-submit');
@@ -228,14 +228,14 @@
                                     array('type' => 'GET',
                                           'data' => 'js:\'rowNumber=\' + $(\'#rowCounter-' . $this->getSearchFormId(). '\').val()',
                                           'beforeSend' => 'js:function(){
-                                            attachLoadingSpinner("' . $this->getSearchFormId() . '", true, "dark");
+                                            makeOrRemoveLoadingSpinner(true, "#' . $this->getSearchFormId() . '", "dark");
                                             }',
                                           'success' => 'js:function(data){
                                             $(\'#' . $this->getRowCounterInputId(). '\').val(parseInt($(\'#' . $this->getRowCounterInputId() . '\').val()) + 1)
                                             $(\'#addExtraAdvancedSearchRowButton-' . $this->getSearchFormId() . '\').parent().before(data);
                                             rebuildDynamicSearchRowNumbersAndStructureInput("' . $this->getSearchFormId() . '");
                                             resolveClearLinkPrefixLabelAndVisibility("' . $this->getSearchFormId() . '");
-                                            attachLoadingSpinner("' . $this->getSearchFormId() . '", false);
+                                            makeOrRemoveLoadingSpinner(false, "#' . $this->getSearchFormId() . '");
                                           }'),
                                     array('id' => 'addExtraAdvancedSearchRowButton-' . $this->getSearchFormId(), 'namespace' => 'add'));
             // End Not Coding Standard
@@ -248,7 +248,7 @@
 
         protected function getAddFieldLabelContent()
         {
-            return Yii::t('Default', 'Add criteria');
+            return Zurmo::t('ZurmoModule', 'Add criteria');
         }
 
         protected function renderAfterFormLayout($form)
@@ -303,7 +303,7 @@
             {
                 $style3 = 'display:none;';
             }
-            $content  = ZurmoHtml::link(Yii::t('Default', 'Modify Structure'), '#',
+            $content  = ZurmoHtml::link(Zurmo::t('ZurmoModule', 'Modify Structure'), '#',
                             array('id'    => 'show-dynamic-search-structure-div-link-' . $this->getSearchFormId() . '',
                                   'style' => $style1));
             $content .= ZurmoHtml::tag('div',
@@ -321,7 +321,7 @@
                                          'name'  => $this->getStructureInputName(),
                                          'class' => 'dynamic-search-structure-input');
             $content             = $form->textField($this->model, 'dynamicStructure', $idInputHtmlOptions);
-            $content            .= ZurmoHtml::tag('span', array(), Yii::t('Default', 'Search Operator'));
+            $content            .= ZurmoHtml::tag('span', array(), Zurmo::t('ZurmoModule', 'Search Operator'));
             $content            .= $form->error($this->model, 'dynamicStructure');
             return $content;
         }
@@ -353,7 +353,7 @@
 
         protected function getClearSearchLabelContent()
         {
-            return Yii::t('Default', 'Criteria Selected <span class="icon-clear">Z</span>');
+            return Zurmo::t('ZurmoModule', 'Criteria Selected <span class="icon-clear">Z</span>');
         }
 
         protected function getClearSearchLinkStartingStyle()
